**Dec 7, 2022.** We have released Version 1.1 with numerous new estimators, functions, fixes, and enhancements.

See the :ref:`complete list of changes here <whats-new>`.

**Jun 20, 2022.** In anticipation for the Version 1.1, we have released a new release candidate
with some fixes and improvements.

See the :ref:`complete list of changes here <whats-new>`.
..end-first-page